@@ -29,7 +29,7 @@ class ResetPasswordToken(models.Model):
     STATUS = StatusType
     token = models.UUIDField(primary_key=False, default=uuid.uuid4)
     expire_date = models.DateTimeField(null=True)
-    user = models.OneToOneField(
+    user = models.ForeignKey(
         settings.AUTH_USER_MODEL,
         related_name="reset_password",
         on_delete=models.CASCADE,
@@ -42,7 +42,7 @@ class ResetPasswordToken(models.Model):
 
         if not self.id:
             ResetPasswordToken.objects.invalidate_existing_token(user=self.user)
-            self.expire_date = timezone.now() + timedelta(hours=self._get_email_expiration_time())
+            self.expire_date = timezone.now() + timedelta(minutes=self._get_email_expiration_time(),)
             self.send_email()
 
         return super(ResetPasswordToken, self).save(*args, **kwargs)
